physical: 'frequency' is really periodicity

Change-Id: I1007d2a7104fa07351c89c52a860cde83b2d509c
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/physical.hpp b/physical.hpp
index 3d99066..e588de2 100644
--- a/physical.hpp
+++ b/physical.hpp
@@ -69,10 +69,10 @@
      */
     SysfsLed& led;
 
     /** @brief Frequency range that the LED can operate on.
      *  Will be removed when frequency is put into interface
      */
-    uint32_t frequency;
+    uint32_t periodMs;
 
     /** @brief reads sysfs and then setsup the parameteres accordingly
      *
@@ -69,10 +69,10 @@
     SysfsLed& led;
 
-    /** @brief Frequency range that the LED can operate on.
-     *  Will be removed when frequency is put into interface
+    /** @brief The period that the LED will operate on, in milliseconds
+     *  Will be removed when periodicity is put into interface
      */